/*
    Copyright (c) 2009 by Joseph Devietti (devietti@cs.washington.edu).

    This file is part of my DMP ASPLOS 2009 Presentation (DAP).

    DAP is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DAP is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DAP.  If not, see <http://www.gnu.org/licenses/>.
*/ 

﻿package  {
	
	import flash.display.Sprite;
	import flash.display.SWFVersion;
	import flash.events.*;
	import flash.text.*;
	import flash.system.Security;
	import flash.external.ExternalInterface;
	
	/**
	 * Simple movie that tests whether the Flash player security privileges are setup correctly 
	 * to allow powerpoint interactions to work correctly.
	 * @author Joe Devietti
	 */
	public class FlashTest extends Sprite {
		
	public function FlashTest() {
		if (stage) init();
		else addEventListener(Event.ADDED_TO_STAGE, init);
	}
	
	private function click(e:Event):void {
		if ( ExternalInterface.available ) {
			ExternalInterface.call( "gotoNextSlide" );
		}
	}
	
	private function check(e:Event):void {
		const WIDTH:int = 300;
		
		// draw background
		this.graphics.beginFill( 0x99CCFF ); // blue
		this.graphics.drawRect( 0, 0, WIDTH, 200 );
		
		var t:TextField = new TextField();
		t.autoSize = TextFieldAutoSize.LEFT;
		t.wordWrap = true;
		t.width = WIDTH;
		addChild( t );
		
		// check security settings
		var msg:String = "1. ";
		if ( Security.sandboxType != Security.LOCAL_TRUSTED ) {
			msg += "Flash movie permissions are "+Security.sandboxType+" but should be "+Security.LOCAL_TRUSTED+"!\n";
			msg += "Please add "+root.loaderInfo.url+" as a trusted file in the Flash Security Settings Manager.";
		} else {
			msg += "Flash movie permissions are fine.";
		}
		msg += "\n";
		
		// check version
		msg += "2. ";
		const REQD_VERSION:uint = SWFVersion.FLASH10;
		if ( root.loaderInfo.swfVersion != REQD_VERSION ) {
			msg += "You're running Flash Player version " + root.loaderInfo.swfVersion + " but this presentation requires version "+REQD_VERSION+"!";
		} else {
			msg += "Flash Player version is fine.";
		}
		msg += "\n";
		
		// check powerpoint interaction
		msg += "3. ";
		if ( !ExternalInterface.available ) {
			msg += "Powerpoint interaction is broken!";
		} else {
			msg += "Powerpoint interaction should work.  Click this blue box and you should see a red box appear below.";
			stage.addEventListener( MouseEvent.CLICK, click );
		}
		
		// can only set text property once if you want wordwrap
		t.text = msg;
	}
	
	private function init(e:Event = null):void {
		removeEventListener(Event.ADDED_TO_STAGE, init);
		// entry point
		
		// need to wait for movie to load completely
		root.loaderInfo.addEventListener( Event.INIT, check );
	}
	
	} // end class
	
} // end package